==> infima_client-0.186.0-py3-none-any.whl: infima_client/api/prediction_service/prediction_service_get_portfolio_look_ahead.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.portfolio_look_ahead_prediction import PortfolioLookAheadPrediction
from ...models.portfolio_look_ahead_prediction_bad_request import (
    PortfolioLookAheadPredictionBadRequest,
)
from ...models.portfolio_look_ahead_prediction_error import (
    PortfolioLookAheadPredictionError,
)
from ...models.portfolio_look_ahead_prediction_not_found import (
    PortfolioLookAheadPredictionNotFound,
)
from ...models.portfolio_look_ahead_prediction_request import (
    PortfolioLookAheadPredictionRequest,
)
from ...models.portfolio_look_ahead_prediction_unauthorized import (
    PortfolioLookAheadPredictionUnauthorized,
)
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: PortfolioLookAheadPredictionRequest,
) -> Dict[str, Any]:
    url = "{}/api/v1/predictions/portfolio/look_ahead".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[
    Union[
        PortfolioLookAheadPrediction,
        PortfolioLookAheadPredictionBadRequest,
        PortfolioLookAheadPredictionUnauthorized,
        PortfolioLookAheadPredictionNotFound,
        PortfolioLookAheadPredictionError,
    ]
]:
    if response.status_code == 200:
        response_200 = PortfolioLookAheadPrediction.from_dict(response.json())

        return response_200
    if response.status_code == 400:
        response_400 = PortfolioLookAheadPredictionBadRequest.from_dict(response.json())

        return response_400
    if response.status_code == 401:
        response_401 = PortfolioLookAheadPredictionUnauthorized.from_dict(
            response.json()
        )

        return response_401
    if response.status_code == 404:
        response_404 = PortfolioLookAheadPredictionNotFound.from_dict(response.json())

        return response_404
    if response.status_code == 500:
        response_500 = PortfolioLookAheadPredictionError.from_dict(response.json())

        return response_500
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[
    Union[
        PortfolioLookAheadPrediction,
        PortfolioLookAheadPredictionBadRequest,
        PortfolioLookAheadPredictionUnauthorized,
        PortfolioLookAheadPredictionNotFound,
        PortfolioLookAheadPredictionError,
    ]
]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: PortfolioLookAheadPredictionRequest,
) -> Response[
    Union[
        PortfolioLookAheadPrediction,
        PortfolioLookAheadPredictionBadRequest,
        PortfolioLookAheadPredictionUnauthorized,
        PortfolioLookAheadPredictionNotFound,
        PortfolioLookAheadPredictionError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    json_body: PortfolioLookAheadPredictionRequest,
) -> Optional[
    Union[
        PortfolioLookAheadPrediction,
        PortfolioLookAheadPredictionBadRequest,
        PortfolioLookAheadPredictionUnauthorized,
        PortfolioLookAheadPredictionNotFound,
        PortfolioLookAheadPredictionError,
    ]
]:
    """
    Weighted aggregate of the historical prepayment look-ahead prediction of the portfolio components.

    Args:

    Returns:
        Either a valid response or an unauthorized, not found or other error.
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: PortfolioLookAheadPredictionRequest,
) -> Response[
    Union[
        PortfolioLookAheadPrediction,
        PortfolioLookAheadPredictionBadRequest,
        PortfolioLookAheadPredictionUnauthorized,
        PortfolioLookAheadPredictionNotFound,
        PortfolioLookAheadPredictionError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    json_body: PortfolioLookAheadPredictionRequest,
) -> Optional[
    Union[
        PortfolioLookAheadPrediction,
        PortfolioLookAheadPredictionBadRequest,
        PortfolioLookAheadPredictionUnauthorized,
        PortfolioLookAheadPredictionNotFound,
        PortfolioLookAheadPredictionError,
    ]
]:
    """ Weighted aggregate of the historical prepayment look-ahead prediction of the portfolio components. """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed

==> infima_client-0.259.0-py3-none-any.whl: infima_client/api/prediction_service/prediction_service_get_portfolio_look_ahead.py <==
from typing import Any, Dict, Optional, Union

import httpx

from ...client import Client
from ...models.portfolio_look_ahead_prediction import PortfolioLookAheadPrediction
from ...models.portfolio_look_ahead_prediction_bad_request import (
    PortfolioLookAheadPredictionBadRequest,
)
from ...models.portfolio_look_ahead_prediction_error import (
    PortfolioLookAheadPredictionError,
)
from ...models.portfolio_look_ahead_prediction_not_found import (
    PortfolioLookAheadPredictionNotFound,
)
from ...models.portfolio_look_ahead_prediction_unauthorized import (
    PortfolioLookAheadPredictionUnauthorized,
)
from ...models.prediction_service_get_portfolio_look_ahead_json_body import (
    PredictionService_GetPortfolioLookAheadJsonBody,
)
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: PredictionService_GetPortfolioLookAheadJsonBody,
) -> Dict[str, Any]:
    url = "{}/api/v1/predictions/portfolio/look_ahead".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": client.get_cookies(),
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(
    *, response: httpx.Response
) -> Optional[
    Union[
        PortfolioLookAheadPrediction,
        PortfolioLookAheadPredictionBadRequest,
        PortfolioLookAheadPredictionUnauthorized,
        PortfolioLookAheadPredictionNotFound,
        PortfolioLookAheadPredictionError,
    ]
]:
    if response.status_code == 200:
        response_200 = PortfolioLookAheadPrediction.from_dict(response.json())

        return response_200
    if response.status_code == 400:
        response_400 = PortfolioLookAheadPredictionBadRequest.from_dict(response.json())

        return response_400
    if response.status_code == 401:
        response_401 = PortfolioLookAheadPredictionUnauthorized.from_dict(
            response.json()
        )

        return response_401
    if response.status_code == 404:
        response_404 = PortfolioLookAheadPredictionNotFound.from_dict(response.json())

        return response_404
    if response.status_code == 500:
        response_500 = PortfolioLookAheadPredictionError.from_dict(response.json())

        return response_500
    return None


def _build_response(
    *, response: httpx.Response
) -> Response[
    Union[
        PortfolioLookAheadPrediction,
        PortfolioLookAheadPredictionBadRequest,
        PortfolioLookAheadPredictionUnauthorized,
        PortfolioLookAheadPredictionNotFound,
        PortfolioLookAheadPredictionError,
    ]
]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: PredictionService_GetPortfolioLookAheadJsonBody,
) -> Response[
    Union[
        PortfolioLookAheadPrediction,
        PortfolioLookAheadPredictionBadRequest,
        PortfolioLookAheadPredictionUnauthorized,
        PortfolioLookAheadPredictionNotFound,
        PortfolioLookAheadPredictionError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    json_body: PredictionService_GetPortfolioLookAheadJsonBody,
) -> Optional[
    Union[
        PortfolioLookAheadPrediction,
        PortfolioLookAheadPredictionBadRequest,
        PortfolioLookAheadPredictionUnauthorized,
        PortfolioLookAheadPredictionNotFound,
        PortfolioLookAheadPredictionError,
    ]
]:
    """
    Weighted aggregate of the historical prepayment look-ahead prediction of the portfolio components.

    Args:

    Returns:
        Either a valid response or an unauthorized, not found or other error.
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: PredictionService_GetPortfolioLookAheadJsonBody,
) -> Response[
    Union[
        PortfolioLookAheadPrediction,
        PortfolioLookAheadPredictionBadRequest,
        PortfolioLookAheadPredictionUnauthorized,
        PortfolioLookAheadPredictionNotFound,
        PortfolioLookAheadPredictionError,
    ]
]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    json_body: PredictionService_GetPortfolioLookAheadJsonBody,
) -> Optional[
    Union[
        PortfolioLookAheadPrediction,
        PortfolioLookAheadPredictionBadRequest,
        PortfolioLookAheadPredictionUnauthorized,
        PortfolioLookAheadPredictionNotFound,
        PortfolioLookAheadPredictionError,
    ]
]:
    """ Weighted aggregate of the historical prepayment look-ahead prediction of the portfolio components. """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed
